==> lein-template-0.1.0-20151123.131235-14.jar: leiningen/new/zou/project.clj <==
(def zou-version "0.1.0-SNAPSHOT")

(defproject {{raw-name}} "0.1.0-SNAPSHOT"
  :description "FIXME: write description"
  :min-lein-version "2.5.2"{{#cljs?}}
  :clean-targets ^{:protect false} [:target-path "resources/public/js/dist" "out"]{{/cljs?}}
  :repositories [["rkworks-snapshots"
                  {:url "https://s3.amazonaws.com/rkworks/snapshots"
                   :snapshots true}]]
  :uberjar-name "{{uberjar-name}}"
  :repl-options {:init-ns zou.framework.repl
                 :init (zou.framework.core/boot-core!)}
  :dependencies [[org.clojure/clojure "1.7.0"]
                 [zou ~zou-version]{{#h2?}}
                 [com.h2database/h2 "1.4.190"]{{/h2?}}{{#postgresql?}}
                 [org.postgresql/posgresql "9.4-1205-jdbc41"]{{/postgresql?}}{{#mysql?}}
                 [mysql/mysql-connector-java "5.1.37"]{{/mysql?}}{{#db?}}
                 [org.clojure/java.jdbc "0.4.2"]{{/db?}}{{#cljs?}}
                 [org.clojure/clojurescript "1.7.170" :scope "provided"]{{/cljs?}}{{#enlive?}}
                 [enlive "1.1.6"]{{/enlive?}}{{#hiccup?}}
                 [hiccup "1.0.5"]{{/hiccup?}}]
  :plugins [[lein-environ "1.0.1"]{{#cljs?}}
            [rkworks/lein-baum "0.1.0"]
            [lein-cljsbuild "1.1.1"]{{/cljs?}}]{{#cljs?}}
  :cljsbuild {import "resources/zou/config/cljsbuild.edn"}{{/cljs?}}
  :profiles {:uberjar {:env {:prod true}
                       :aot :all{{#cljs?}}
                       :hooks [leiningen.cljsbuild]{{/cljs?}}}
             :dev {:env {:zou-env :dev}{{#cljs?}}
                   :repl-options {:nrepl-middleware [cemerick.piggieback/wrap-cljs-repl]}{{/cljs?}}
                   :dependencies [[zou/devel ~zou-version]{{#midje?}}
                                  [midje "1.7.0"]{{/midje?}}{{#cljs?}}
                                  [com.cemerick/piggieback "0.2.1"]{{/cljs?}}]
                   :plugins [{{#midje?}}[lein-midje "3.1.3"]{{/midje?}}]}}
  :main {{namespace}}.main)

==> lein-template-0.1.0-20151124.090623-18.jar: leiningen/new/zou/project.clj <==
(def zou-version "0.1.0-SNAPSHOT")

(defproject {{raw-name}} "0.1.0-SNAPSHOT"
  :description "FIXME: write description"
  :min-lein-version "2.5.2"{{#cljs?}}
  :clean-targets ^{:protect false} [:target-path "resources/public/js/dist" "out"]{{/cljs?}}
  :repositories [["rkworks-snapshots"
                  {:url "https://s3.amazonaws.com/rkworks/snapshots"
                   :snapshots true}]]
  :uberjar-name "{{uberjar-name}}"
  :repl-options {:init-ns zou.framework.repl
                 :init (zou.framework.core/boot-core!)}
  :dependencies [[org.clojure/clojure "1.7.0"]
                 [zou ~zou-version]{{#h2?}}
                 [com.h2database/h2 "1.4.190"]{{/h2?}}{{#postgresql?}}
                 [org.postgresql/posgresql "9.4-1205-jdbc41"]{{/postgresql?}}{{#mysql?}}
                 [mysql/mysql-connector-java "5.1.37"]{{/mysql?}}{{#db?}}
                 [org.clojure/java.jdbc "0.4.2"]{{/db?}}{{#cljs?}}
                 [org.clojure/clojurescript "1.7.170" :scope "provided"]{{/cljs?}}{{#enlive?}}
                 [enlive "1.1.6"]{{/enlive?}}{{#hiccup?}}
                 [hiccup "1.0.5"]{{/hiccup?}}]
  :plugins [[lein-environ "1.0.1"]{{#cljs?}}
            [rkworks/lein-baum "0.1.0"]
            [lein-cljsbuild "1.1.1"]{{/cljs?}}]{{#cljs?}}
  :cljsbuild {import "resources/zou/config/cljsbuild.edn"}{{/cljs?}}
  :profiles {:uberjar {:env {:prod true}
                       :aot :all{{#cljs?}}
                       :hooks [leiningen.cljsbuild]{{/cljs?}}}
             :dev {:env {:zou-env :dev}{{#cljs?}}
                   :repl-options {:nrepl-middleware [cemerick.piggieback/wrap-cljs-repl]}{{/cljs?}}
                   :dependencies [[zou/devel ~zou-version {{^cljs?}}:exclusions [zou/cljs-devel]{{/cljs?}}]{{#midje?}}
                                  [midje "1.7.0"]{{/midje?}}{{#cljs?}}
                                  [com.cemerick/piggieback "0.2.1"]{{/cljs?}}]
                   :plugins [{{#midje?}}[lein-midje "3.1.3"]{{/midje?}}]}}
  :main {{namespace}}.main)
